summaryrefslogtreecommitdiffhomepage
path: root/src/external/stb_image_resize.h
diff options
context:
space:
mode:
authorRay <[email protected]>2017-01-18 23:27:41 +0100
committerRay <[email protected]>2017-01-18 23:27:41 +0100
commit7cd24d27061cb08f818692961beb1ecb4a74445e (patch)
tree6b79154628edb1ac05969767c08612c1e61240db /src/external/stb_image_resize.h
parent3b120bd7d936b5e6b730caa60709c6d73865d146 (diff)
downloadraylib-7cd24d27061cb08f818692961beb1ecb4a74445e.tar.gz
raylib-7cd24d27061cb08f818692961beb1ecb4a74445e.zip
Updated stb external libraries
Diffstat (limited to 'src/external/stb_image_resize.h')
-rw-r--r--src/external/stb_image_resize.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/external/stb_image_resize.h b/src/external/stb_image_resize.h
index 4cabe540..5214ad6e 100644
--- a/src/external/stb_image_resize.h
+++ b/src/external/stb_image_resize.h
@@ -1,4 +1,4 @@
/* stb_image_resize - v0.91 - public domain image resizing
by Jorge L Rodriguez (@VinoBS) - 2014
http://github.com/nothings/stb
@@ -154,8 +154,10 @@
ADDITIONAL CONTRIBUTORS
Sean Barrett: API design, optimizations
+ Aras Pranckevicius: bugfix
REVISIONS
+ 0.92 (2017-01-02) fix integer overflow on large (>2GB) images
0.91 (2016-04-02) fix warnings; fix handling of subpixel regions
0.90 (2014-09-17) first released version
@@ -1239,11 +1241,11 @@ static void stbir__decode_scanline(stbir__info* stbir_info, int n)
int type = stbir_info->type;
int colorspace = stbir_info->colorspace;
int input_w = stbir_info->input_w;
- int input_stride_bytes = stbir_info->input_stride_bytes;
+ size_t input_stride_bytes = stbir_info->input_stride_bytes;
float* decode_buffer = stbir__get_decode_buffer(stbir_info);
stbir_edge edge_horizontal = stbir_info->edge_horizontal;
stbir_edge edge_vertical = stbir_info->edge_vertical;
- int in_buffer_row_offset = stbir__edge_wrap(edge_vertical, n, stbir_info->input_h) * input_stride_bytes;
+ size_t in_buffer_row_offset = stbir__edge_wrap(edge_vertical, n, stbir_info->input_h) * input_stride_bytes;
const void* input_data = (char *) stbir_info->input_data + in_buffer_row_offset;
int max_x = input_w + stbir_info->horizontal_filter_pixel_margin;
int decode = STBIR__DECODE(type, colorspace);
@@ -1,4 +1,4 @@
-/* stb_image_resize - v0.91 - public domain image resizing
+/* stb_image_resize - v0.92 - public domain image resizing
by Jorge L Rodriguez (@VinoBS) - 2014
http://github.com/nothings/stb